@@ -49,8 +49,25 @@
                  position = position,
                  params = list(na.rm = na.rm, ...))
 }
-
 GeomConfint <- ggplot2::ggproto('GeomConfint', ggplot2::GeomRibbon,
+                                required_aes = c("x", "ymin", "ymax"),
+                                draw_group = function(self, data, panel_scales, coord, na.rm = FALSE) {
+                                  if (na.rm) data <- data[stats::complete.cases(self$required_aes), ]
+                                  data <- data[order(data$group, data$x), ]
+                                  data <- self$stairstep_confint(data)
+                                  ggplot2:::GeomRibbon$draw_group(data, panel_scales, coord, na.rm = FALSE)
+                                },
+                                stairstep_confint = function (data) {
+                                  data <- as.data.frame(data)[order(data$x), ]
+                                  n <- nrow(data)
+                                  ys <- rep(1:n, each = 2)[-2 * n]
+                                  xs <- c(1, rep(2:n, each = 2))
+                                  data.frame(x = data$x[xs], ymin = data$ymin[ys], ymax = data$ymax[ys],
+                                             data[xs, setdiff(names(data), c("x", "ymin", "ymax"))])
+                                }
+)
+
+GeomConfint_old <- ggplot2::ggproto('GeomConfint_old', ggplot2::GeomRibbon,
                                 required_aes = c("x", "ymin", "ymax"),
                                 draw_group = function(data, panel_scales, coord, na.rm = FALSE) {
                                   if (na.rm) data <- data[complete.cases(data[c("x", "ymin", "ymax")]), ]
